@@ -47,6 +47,7 @@ const (
 	QuestionAlreadyDeleted           = "error.question.already_deleted"
 	QuestionUnderReview              = "error.question.under_review"
 	QuestionContentCannotEmpty       = "error.question.content_cannot_empty"
+	QuestionContentLessThanMinimum   = "error.question.content_less_than_minumum"
 	AnswerNotFound                   = "error.answer.not_found"
 	AnswerCannotDeleted              = "error.answer.cannot_deleted"
 	AnswerCannotUpdate               = "error.answer.cannot_update"
@@ -77,6 +78,7 @@ const (
 	TagCannotUpdate                  = "error.tag.cannot_update"
 	TagIsUsedCannotDelete            = "error.tag.is_used_cannot_delete"
 	TagAlreadyExist                  = "error.tag.already_exist"
+	TagMinCount                      = "error.tag.minimum_count"
 	RankFailToMeetTheCondition       = "error.rank.fail_to_meet_the_condition"
 	VoteRankFailToMeetTheCondition   = "error.rank.vote_fail_to_meet_the_condition"
 	NoEnoughRankToOperate            = "error.rank.no_enough_rank_to_operate"
@@ -111,6 +113,10 @@ const (
 	MetaObjectNotFound               = "error.meta.object_not_found"
 	BadgeObjectNotFound              = "error.badge.object_not_found"
 	StatusInvalid                    = "error.common.status_invalid"
+	UserStatusInactive               = "error.user.status_inactive"
+	UserStatusSuspendedForever       = "error.user.status_suspended_forever"
+	UserStatusSuspendedUntil         = "error.user.status_suspended_until"
+	UserStatusDeleted                = "error.user.status_deleted"
 )
 
 // user external login reasons
