@@ -180,8 +180,10 @@ func (m *Mentor) initSiteInfoInterface() {
 	}
 
 	interfaceData := map[string]string{
-		"language":  m.userData.Language,
-		"time_zone": localTimezone,
+		"language":          m.userData.Language,
+		"time_zone":         localTimezone,
+		"default_avatar":    "gravatar",
+		"gravatar_base_url": "https://www.gravatar.com/avatar/",
 	}
 	interfaceDataBytes, _ := json.Marshal(interfaceData)
 	_, m.err = m.engine.Context(m.ctx).Insert(&entity.SiteInfo{
@@ -287,7 +289,9 @@ func (m *Mentor) initSiteInfoPrivilegeRank() {
 
 func (m *Mentor) initSiteInfoWrite() {
 	writeData := map[string]interface{}{
+		"min_content":                      6,
 		"restrict_answer":                  true,
+		"min_tags":                         1,
 		"required_tag":                     false,
 		"recommend_tags":                   []string{},
 		"reserved_tags":                    []string{},
