@@ -79,11 +79,11 @@ type QuestionAdd struct {
 	// question title
 	Title string `validate:"required,notblank,gte=6,lte=150" json:"title"`
 	// content
-	Content string `validate:"required,notblank,gte=6,lte=65535" json:"content"`
+	Content string `validate:"gte=0,lte=65535" json:"content"`
 	// html
 	HTML string `json:"-"`
 	// tags
-	Tags []*TagItem `validate:"required,dive" json:"tags"`
+	Tags []*TagItem `validate:"dive" json:"tags"`
 	// user id
 	UserID string `json:"-"`
 	QuestionPermission
@@ -100,12 +100,6 @@ func (req *QuestionAdd) Check() (errFields []*validator.FormErrorField, err erro
 			tag.ParsedText = converter.Markdown2HTML(tag.OriginalText)
 		}
 	}
-	if req.HTML == "" {
-		return append(errFields, &validator.FormErrorField{
-			ErrorField: "content",
-			ErrorMsg:   reason.QuestionContentCannotEmpty,
-		}), errors.BadRequest(reason.QuestionContentCannotEmpty)
-	}
 	return nil, nil
 }
 
@@ -113,13 +107,13 @@ type QuestionAddByAnswer struct {
 	// question title
 	Title string `validate:"required,notblank,gte=6,lte=150" json:"title"`
 	// content
-	Content string `validate:"required,notblank,gte=6,lte=65535" json:"content"`
+	Content string `validate:"gte=0,lte=65535" json:"content"`
 	// html
 	HTML          string `json:"-"`
 	AnswerContent string `validate:"required,notblank,gte=6,lte=65535" json:"answer_content"`
 	AnswerHTML    string `json:"-"`
 	// tags
-	Tags []*TagItem `validate:"required,dive" json:"tags"`
+	Tags []*TagItem `validate:"dive" json:"tags"`
 	// user id
 	UserID              string   `json:"-"`
 	MentionUsernameList []string `validate:"omitempty" json:"mention_username_list"`
@@ -138,19 +132,11 @@ func (req *QuestionAddByAnswer) Check() (errFields []*validator.FormErrorField,
 			tag.ParsedText = converter.Markdown2HTML(tag.OriginalText)
 		}
 	}
-	if req.HTML == "" {
-		errFields = append(errFields, &validator.FormErrorField{
-			ErrorField: "content",
-			ErrorMsg:   reason.QuestionContentCannotEmpty,
-		})
-	}
 	if req.AnswerHTML == "" {
 		errFields = append(errFields, &validator.FormErrorField{
 			ErrorField: "answer_content",
 			ErrorMsg:   reason.AnswerContentCannotEmpty,
 		})
-	}
-	if req.HTML == "" || req.AnswerHTML == "" {
 		return errFields, errors.BadRequest(reason.QuestionContentCannotEmpty)
 	}
 	return nil, nil
@@ -195,12 +181,12 @@ type QuestionUpdate struct {
 	// question title
 	Title string `validate:"required,notblank,gte=6,lte=150" json:"title"`
 	// content
-	Content string `validate:"required,notblank,gte=6,lte=65535" json:"content"`
+	Content string `validate:"gte=0,lte=65535" json:"content"`
 	// html
 	HTML       string   `json:"-"`
 	InviteUser []string `validate:"omitempty"  json:"invite_user"`
 	// tags
-	Tags []*TagItem `validate:"required,dive" json:"tags"`
+	Tags []*TagItem `validate:"dive" json:"tags"`
 	// edit summary
 	EditSummary string `validate:"omitempty" json:"edit_summary"`
 	// user id
@@ -227,12 +213,6 @@ type QuestionUpdateInviteUser struct {
 
 func (req *QuestionUpdate) Check() (errFields []*validator.FormErrorField, err error) {
 	req.HTML = converter.Markdown2HTML(req.Content)
-	if req.HTML == "" {
-		return append(errFields, &validator.FormErrorField{
-			ErrorField: "content",
-			ErrorMsg:   reason.QuestionContentCannotEmpty,
-		}), errors.BadRequest(reason.QuestionContentCannotEmpty)
-	}
 	return nil, nil
 }
 
