@@ -59,8 +59,10 @@ func (r *SiteGeneralReq) FormatSiteUrl() {
 
 // SiteInterfaceReq site interface request
 type SiteInterfaceReq struct {
-	Language string `validate:"required,gt=1,lte=128" form:"language" json:"language"`
-	TimeZone string `validate:"required,gt=1,lte=128" form:"time_zone" json:"time_zone"`
+	Language        string `validate:"required,gt=1,lte=128" form:"language" json:"language"`
+	TimeZone        string `validate:"required,gt=1,lte=128" form:"time_zone" json:"time_zone"`
+	DefaultAvatar   string `validate:"required,oneof=system gravatar" json:"default_avatar"`
+	GravatarBaseURL string `validate:"omitempty" json:"gravatar_base_url"`
 }
 
 // SiteBrandingReq site branding request
@@ -73,7 +75,9 @@ type SiteBrandingReq struct {
 
 // SiteWriteReq site write request
 type SiteWriteReq struct {
+	MinimumContent                 int             `validate:"omitempty,gte=0,lte=65535" json:"min_content"`
 	RestrictAnswer                 bool            `validate:"omitempty" json:"restrict_answer"`
+	MinimumTags                    int             `validate:"omitempty,gte=0,lte=5" json:"min_tags"`
 	RequiredTag                    bool            `validate:"omitempty" json:"required_tag"`
 	RecommendTags                  []*SiteWriteTag `validate:"omitempty,dive" json:"recommend_tags"`
 	ReservedTags                   []*SiteWriteTag `validate:"omitempty,dive" json:"reserved_tags"`
