@@ -899,3 +899,11 @@ func (qs *QuestionCommon) tryToGetQuestionIDFromMsg(ctx context.Context, closeMs
 	questionID = uid.DeShortID(questionID)
 	return questionID
 }
+
+func (qs *QuestionCommon) GetMinimumContentLength(ctx context.Context) (int, error) {
+	siteInfo, err := qs.siteInfoService.GetSiteWrite(ctx)
+	if err != nil {
+		return 6, err
+	}
+	return siteInfo.MinimumContent, nil
+}
