@@ -28,11 +28,11 @@ const Index: FC = () => {
   return (
     <div className="d-flex">
       <div
-        className="position-sticky px-3 border-end pt-4 d-none d-xl-block"
+        className="position-sticky px-3 border-end pt-4 d-none d-lg-block"
         id="pcSideNav">
         <SideNav />
       </div>
-      <div className="flex-fill w-100">
+      <div className="flex-fill w-100 overflow-x-hidden">
         <div className="d-flex justify-content-center px-0 px-md-4">
           <div className="answer-container">
             <Outlet />
